% Calculate the PSD for the Acceleration of the Rigid Aircraft
% considering just Heave Motion. Both, Steady and Unsteady Aerodynamic  

clc
close all
clear all

% Inputs
% Speed V [m/s]
V = 58.3;
% Wing Chord c [m]
c = 0.8;
% Air Density [kg/m3]
p = 1.225;
% Wing Area [m2]
Sw = 10.4;
% Aircraft Cla 
a = 2*pi;
% Aircraft mass m [kg]
m = 600;

% Inputs for the Gust Velocity PSD
 
% RMS of the Gust Velocity [m/s]
sig_g = 1;
% Turbulence's Caractheristic Scale Wavelength [m]
L = 762;

F = [];
PHI_gg = [];
PHI_a_F = [];
PHI_a_F_us = [];

OM = [];
PHI_gg_OM =[];
PHI_a_OM = [];
PHI_a_OM_us = [];

cont = 0;
Int_F = 0;
Int_OM = 0;

Int_a_F =0;
Int_a_OM =0;

Int_a_F_us =0;
Int_a_OM_us =0;

FRF_a =[];
FRF_a_us =[];

i = sqrt (-1);

for j = -3:0.01:1

 cont = cont +1;
 
 f =  10^j;
 OMEGA = 2*pi*f/V;

% Frequency [Hz];
 
 w = 2*pi*f;
 k = w*c/(2*V);
 
% Unsteady Aerodynamic

% Sears' Function

d = 0.1811;
mod = sqrt((d+k)/(d+(pi*d+1)*k+2*pi*k));
if k<0.01
  arg = (-47.095)*(k^5)+(87.297)*(k^4)-(61.470)*(k^3)+(21.917)*(k^2)-(3.664)*k;
else
  arg = 0.982*k-0.597;
endif
S = mod*exp(i*arg);

% Theodorsen's Function

if k<0.5
  C = 1- 0.165/(1-(0.045/k)*i)-0.335/(1-(0.030/k)*i);
else 
  C = 1- 0.165/(1-(0.045/k)*i)-0.335/(1-(0.032/k)*i);
end
 
 frf = (-0.5*p*V*Sw*a)/(-(w^2)*m+(i*w)*(0.5*p*V*Sw*a));
 frf_us = (-0.5*p*V*Sw*a)*S/(-(w^2)*m+(i*w)*(0.5*p*V*Sw*a)*C);
 FRF_a = [FRF_a abs(-(w^2)*frf)];
 FRF_a_us = [FRF_a_us abs(-(w^2)*frf_us)];
 
 F = [F f];
 PHI_gg = [PHI_gg (sig_g^2)*(2*L/V)*(1+(8/3)*((1.339*OMEGA*L)^2))/((1+(1.339*OMEGA*L)^2)^(11/6))];
 PHI_a_F = [PHI_a_F PHI_gg(cont)*((abs(-(w^2)*frf))^2)];
 PHI_a_F_us = [PHI_a_F_us PHI_gg(cont)*((abs(-(w^2)*frf_us))^2)];
 
 
 % Scaled Frequency [rad/m]
 
 jo = j-1;
 wo = (10^jo)*V; 
 ko = wo*c/(2*V);
 
 % Unsteady Aerodynamic

% Sears' Function

d = 0.1811;
modo = sqrt((d+ko)/(d+(pi*d+1)*ko+2*pi*ko));
if ko<0.01
  argo = (-47.095)*(ko^5)+(87.297)*(ko^4)-(61.470)*(ko^3)+(21.917)*(ko^2)-(3.664)*ko;
else
  argo = 0.982*ko-0.597;
endif
So = modo*exp(i*argo);

% Theodorsen's Function

if ko<0.5
  Co = 1- 0.165/(1-(0.045/ko)*i)-0.335/(1-(0.030/ko)*i);
else 
  Co = 1- 0.165/(1-(0.045/ko)*i)-0.335/(1-(0.032/ko)*i);
end

 
 frf_o = (-0.5*p*V*Sw*a)/(-(wo^2)*m+(i*wo)*(0.5*p*V*Sw*a));
 frf_o_us = (-0.5*p*V*Sw*a)*So/(-(wo^2)*m+(i*wo)*(0.5*p*V*Sw*a)*Co);
 OM = [OM wo/V];
 PHI_gg_OM = [PHI_gg_OM (sig_g^2)*(L/pi)*(1+(8/3)*((1.339*(wo/V)*L)^2))/((1+(1.339*(wo/V)*L)^2)^(11/6))];
 PHI_a_OM = [PHI_a_OM PHI_gg_OM(cont)*((abs(-(wo^2)*frf_o))^2)];
 PHI_a_OM_us = [PHI_a_OM_us PHI_gg_OM(cont)*((abs(-(wo^2)*frf_o_us))^2)]; 
 
 
 if cont>2 
   
 Int_F = Int_F+(F(cont)-F(cont-1))*(PHI_gg(cont)+PHI_gg(cont-1))/2;
 Int_OM = Int_OM+(OM(cont)-OM(cont-1))*(PHI_gg_OM(cont)+PHI_gg_OM(cont-1))/2;
 Int_a_F = Int_a_F+(F(cont)-F(cont-1))*(PHI_a_F(cont)+PHI_a_F(cont-1))/2;
 Int_a_OM = Int_a_OM+(OM(cont)-OM(cont-1))*(PHI_a_OM(cont)+PHI_a_OM(cont-1))/2;
 Int_a_F_us = Int_a_F_us+(F(cont)-F(cont-1))*(PHI_a_F_us(cont)+PHI_a_F_us(cont-1))/2;
 Int_a_OM_us = Int_a_OM_us+(OM(cont)-OM(cont-1))*(PHI_a_OM_us(cont)+PHI_a_OM_us(cont-1))/2;

 
 endif


  
 end

loglog(F,PHI_gg,'b','linewidth',2)
xlabel('Frequency [Hz]')
ylabel('PSD Gust Velocity [(m/s)^2/Hz]')
set(gca,'fontsize',15,'LineWidth',1.5)

figure
loglog(OM,PHI_gg_OM,'b','linewidth',2)
xlabel('Scaled Frequency [rad/m]')
ylabel('PSD Gust Velocity [(m/s)^2/(rad/m)]')
set(gca,'fontsize',15,'LineWidth',1.5)

figure
loglog(F,FRF_a,'b','linewidth',2,F,FRF_a_us,'g','linewidth',2)
xlabel('Frequency [Hz]')
ylabel('FRF - Acceleration [((m/s^2)/(m/s)]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Steady Aerodynamic', 'Unsteady Aerodynamic','Location','northwest')



figure
loglog(F,PHI_a_F,'b','linewidth',2,F,PHI_a_F_us,'g','linewidth',2)
xlabel('Frequency [Hz]')
ylabel('PSD Acceleration [(m/s^2)^2/Hz]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Steady Aerodynamic', 'Unsteady Aerodynamic','Location','northwest')


figure
loglog(OM,PHI_a_OM,'b','linewidth',2,OM,PHI_a_OM_us,'g','linewidth',2)
xlabel('Scaled Frequency [rad/m]')
ylabel('PSD Acceleration [(m/s^2)^2/(rad/m)]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Steady Aerodynamic', 'Unsteady Aerodynamic')


txt1 = ['Gust Velocity RMS (m/s) - PHI_gg integal, Frequency (Hz): ',num2str(sqrt(Int_F))];
txt2 = ['Gust Velocity RMS (m/s) - PHI_gg integal, Scaled Frequency (rad/m): ',num2str(sqrt(Int_OM))];
disp(txt1);
disp(txt2);

txt3 = ['Acceleration RMS (m/s^2) - PHI_acc integal - Steady, Frequency (Hz): ',num2str(sqrt(Int_a_F))];
txt4 = ['Acceleration RMS (m/s^2) - PHI_acc integal - Steady, Scaled Frequency (rad/m): ',num2str(sqrt(Int_a_OM))];
disp(txt3);
disp(txt4);

txt5 = ['Acceleration RMS (m/s^2) - PHI_acc integal - Unsteady, Frequency (Hz): ',num2str(sqrt(Int_a_F_us))];
txt6 = ['Acceleration RMS (m/s^2) - PHI_acc integal - Unsteady, Scaled Frequency (rad/m): ',num2str(sqrt(Int_a_OM_us))];
disp(txt5);
disp(txt6);

