% Calculate the PSD for the Acceleration of the Rigid Aircraft
% considering Heave and Pitch Motion. Both, Steady and Unsteady Aerodynamic  

clc
close all
clear all


% Inputs
% Speed V [m/s]
V = 58.3;
% Wing Chord c [m]
c = 0.8;
% Air Density [kg/m3]
p = 1.225;
% Wing Area [m2]
Sw = 10.4;
% Aircraft Cla 
a = 2*pi;
% Tail Area [m2]
St = 1.025;
% AC wing to MC Aircraft lw [m]
lw = 0.2;
% AC Tail to MC Aircraft lt [m]
lt = 4;
% Tail Cla 
at = 2*pi;
% Downwash keps = deps/da
keps = 0.4;
% Aircraft mass m [kg]
m = 600;
% Aircraft Inertia I [kg.m2]
I = 400;



% Longitudinal Aerodynamic Derivatives

Za = -0.5*p*(V^2)*(Sw*a+ (1-keps)*St*at);
Zzp = -0.5*p*V*(Sw*a+ (1-keps)*St*at);
Zgw = -0.5*p*V*Sw*a;
Zgt = -0.5*p*V*(1-keps)*St*at;
Zap = -0.5*p*V*St*at*lt;

Ma = 0.5*p*(V^2)*(Sw*a*lw - (1-keps)*St*at*lt);
Mzp = 0.5*p*V*(Sw*a*lw - (1-keps)*St*at*lt);
Mgw = 0.5*p*V*Sw*a*lw;
Mgt = -0.5*p*V*(1-keps)*St*at*lt;
Map = -0.5*p*V*St*at*(lt^2);





% Motion Equation Coefficients Matrices

Ca = [m 0 ; 0 I];
Cv = [-Zzp -Zap; -Mzp -Map];
Cd = [0 -Za; 0 -Ma];
Cgw = [Zgw; Mgw];
Cgt = [Zgt; Mgt];




% Inputs for the Gust Velocity PSD
 
% RMS of the Gust Velocity [m/s]
sig_g = 1;
% Turbulence's Caractheristic Scale Wavelength [m]
L = 762;


F = [];
PHI_gg = [];
PHI_a_F = [];
PHI_a_F_us = [];
PHI_a_F_us_t = [];
PHI_a_F_us_wle = [];

OM = [];
PHI_gg_OM =[];
PHI_a_OM = [];
PHI_a_OM_us = [];

cont = 0;
Int_F = 0;
Int_OM = 0;

Int_a_F =0;
Int_a_OM =0;

Int_a_F_us =0;
Int_a_F_us_t =0;
Int_a_F_us_wle =0;
Int_a_OM_us =0;

FRF_a =[];
FRF_a_us =[];
FRF_a_us_t =[];
FRF_a_us_wle =[];

i = sqrt (-1);

for j = -3:0.01:1

 cont = cont +1;
 
 f =  10^j;
 OMEGA = 2*pi*f/V;

% Frequency [Hz];
 
 w = 2*pi*f;
 k = w*c/(2*V);
 
% Unsteady Aerodynamic

% Sears' Function

d = 0.1811;
mod = sqrt((d+k)/(d+(pi*d+1)*k+2*pi*k));
if k<0.01
  arg = (-47.095)*(k^5)+(87.297)*(k^4)-(61.470)*(k^3)+(21.917)*(k^2)-(3.664)*k;
else
  arg = 0.982*k-0.597;
endif
S = mod*exp(i*arg);

% Theodorsen's Function

if k<0.5
  C = 1- 0.165/(1-(0.045/k)*i)-0.335/(1-(0.030/k)*i);
else 
  C = 1- 0.165/(1-(0.045/k)*i)-0.335/(1-(0.032/k)*i);
end
 
 frf = inv((-w^2)*Ca+(i*w)*Cv+Cd)*(Cgw+(exp(i*w*(lt+lw)/V))*Cgt);
 frf_us = inv((-w^2)*Ca+(i*w)*Cv+Cd)*(Cgw+(exp(i*w*(lt+lw)/V))*Cgt)*S;
 frf_us_t = [1 lt]*frf_us;
 frf_us_wle = [1 -(lw+0.25*c)]*frf_us;
 FRF_a = [FRF_a abs(-(w^2)*frf(1))];
 FRF_a_us = [FRF_a_us abs(-(w^2)*frf_us(1))];
 FRF_a_us_t = [FRF_a_us_t abs(-(w^2)*frf_us_t)]; 
 FRF_a_us_wle = [FRF_a_us_wle abs(-(w^2)*frf_us_wle)];  
 
 F = [F f];
 PHI_gg = [PHI_gg (sig_g^2)*(2*L/V)*(1+(8/3)*((1.339*OMEGA*L)^2))/((1+(1.339*OMEGA*L)^2)^(11/6))];
 PHI_a_F = [PHI_a_F PHI_gg(cont)*((abs(-(w^2)*frf(1)))^2)];
 PHI_a_F_us = [PHI_a_F_us PHI_gg(cont)*((abs(-(w^2)*frf_us(1)))^2)];
 PHI_a_F_us_t = [PHI_a_F_us_t PHI_gg(cont)*((abs(-(w^2)*frf_us_t))^2)];
 PHI_a_F_us_wle = [PHI_a_F_us_wle PHI_gg(cont)*((abs(-(w^2)*frf_us_wle))^2)];
 
 
 % Scaled Frequency [rad/m]
 
 jo = j-1;
 wo = (10^jo)*V; 
 ko = wo*c/(2*V);
 
 % Unsteady Aerodynamic

% Sears' Function

d = 0.1811;
modo = sqrt((d+ko)/(d+(pi*d+1)*ko+2*pi*ko));
if ko<0.01
  argo = (-47.095)*(ko^5)+(87.297)*(ko^4)-(61.470)*(ko^3)+(21.917)*(ko^2)-(3.664)*ko;
else
  argo = 0.982*ko-0.597;
endif
So = modo*exp(i*argo);

% Theodorsen's Function

if ko<0.5
  Co = 1- 0.165/(1-(0.045/ko)*i)-0.335/(1-(0.030/ko)*i);
else 
  Co = 1- 0.165/(1-(0.045/ko)*i)-0.335/(1-(0.032/ko)*i);
end

 
 frf_o = inv((-wo^2)*Ca+(i*wo)*Cv+Cd)*(Cgw+(exp(i*wo*(lt+lw)/V))*Cgt);
 frf_o_us = inv((-wo^2)*Ca+(i*wo)*Cv+Cd)*(Cgw+(exp(i*wo*(lt+lw)/V))*Cgt)*So;
 OM = [OM wo/V];
 PHI_gg_OM = [PHI_gg_OM (sig_g^2)*(L/pi)*(1+(8/3)*((1.339*(wo/V)*L)^2))/((1+(1.339*(wo/V)*L)^2)^(11/6))];
 PHI_a_OM = [PHI_a_OM PHI_gg_OM(cont)*((abs(-(wo^2)*frf_o(1)))^2)];
 PHI_a_OM_us = [PHI_a_OM_us PHI_gg_OM(cont)*((abs(-(wo^2)*frf_o_us(1)))^2)]; 
 
 
 if cont>2 
   
 Int_F = Int_F+(F(cont)-F(cont-1))*(PHI_gg(cont)+PHI_gg(cont-1))/2;
 Int_OM = Int_OM+(OM(cont)-OM(cont-1))*(PHI_gg_OM(cont)+PHI_gg_OM(cont-1))/2;
 Int_a_F = Int_a_F+(F(cont)-F(cont-1))*(PHI_a_F(cont)+PHI_a_F(cont-1))/2;
 Int_a_OM = Int_a_OM+(OM(cont)-OM(cont-1))*(PHI_a_OM(cont)+PHI_a_OM(cont-1))/2;
 Int_a_F_us = Int_a_F_us+(F(cont)-F(cont-1))*(PHI_a_F_us(cont)+PHI_a_F_us(cont-1))/2;
 Int_a_F_us_t = Int_a_F_us_t+(F(cont)-F(cont-1))*(PHI_a_F_us_t(cont)+PHI_a_F_us_t(cont-1))/2;
 Int_a_F_us_wle = Int_a_F_us_wle+(F(cont)-F(cont-1))*(PHI_a_F_us_wle(cont)+PHI_a_F_us_wle(cont-1))/2;
 Int_a_OM_us = Int_a_OM_us+(OM(cont)-OM(cont-1))*(PHI_a_OM_us(cont)+PHI_a_OM_us(cont-1))/2;

 
 endif


  
 end

loglog(F,PHI_gg,'b','linewidth',2)
xlabel('Frequency [Hz]')
ylabel('PSD Gust Velocity [(m/s)^2/Hz]')
set(gca,'fontsize',15,'LineWidth',1.5)

figure
loglog(OM,PHI_gg_OM,'b','linewidth',2)
xlabel('Scaled Frequency [rad/m]')
ylabel('PSD Gust Velocity [(m/s)^2/(rad/m)]')
set(gca,'fontsize',15,'LineWidth',1.5)

figure
loglog(F,FRF_a,'b','linewidth',2,F,FRF_a_us,'g','linewidth',2)
xlabel('Frequency [Hz]')
ylabel('FRF - Acceleration [((m/s^2)/(m/s)]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Steady Aerodynamic', 'Unsteady Aerodynamic','Location','northwest')



figure
loglog(F,PHI_a_F,'b','linewidth',2,F,PHI_a_F_us,'g','linewidth',2)
xlabel('Frequency [Hz]')
ylabel('PSD Acceleration [(m/s^2)^2/Hz]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Steady Aerodynamic', 'Unsteady Aerodynamic')

figure
loglog(OM,PHI_a_OM,'b','linewidth',2,OM,PHI_a_OM_us,'g','linewidth',2)
xlabel('Scaled Frequency [rad/m]')
ylabel('PSD Acceleration [(m/s^2)^2/(rad/m)]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Steady Aerodynamic', 'Unsteady Aerodynamic')

figure
loglog(F,PHI_a_F_us,'g','linewidth',2,F,PHI_a_F_us_t,'b','linewidth',2,F,PHI_a_F_us_wle,'r','linewidth',2)
xlabel('Frequency [Hz]')
ylabel('PSD Acceleration [(m/s^2)^2/Hz]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('CoM', 'Tail','Wing LE')


txt1 = ['Gust Velocity RMS (m/s) - PHI_gg integal, Frequency (Hz): ',num2str(sqrt(Int_F))];
txt2 = ['Gust Velocity RMS (m/s) - PHI_gg integal, Scaled Frequency (rad/m): ',num2str(sqrt(Int_OM))];
disp(txt1);
disp(txt2);

txt3 = ['Acceleration CoM RMS (m/s^2) - PHI_acc integal - Steady, Frequency (Hz): ',num2str(sqrt(Int_a_F))];
txt4 = ['Acceleration CoM RMS (m/s^2) - PHI_acc integal - Steady, Scaled Frequency (rad/m): ',num2str(sqrt(Int_a_OM))];
disp(txt3);
disp(txt4);

txt5 = ['Acceleration CoM RMS (m/s^2) - PHI_acc integal - Unsteady, Frequency (Hz): ',num2str(sqrt(Int_a_F_us))];
txt6 = ['Acceleration CoM RMS (m/s^2) - PHI_acc integal - Unsteady, Scaled Frequency (rad/m): ',num2str(sqrt(Int_a_OM_us))];
disp(txt5);
disp(txt6);

txt7 = ['Acceleration Tail RMS (m/s^2) - PHI_acc integal - Unsteady, Frequency (Hz): ',num2str(sqrt(Int_a_F_us_t))];
txt8 = ['Acceleration Wing LE RMS (m/s^2) - PHI_acc integal - Unsteady, Frequency (Hz): ',num2str(sqrt(Int_a_F_us_wle))];
disp(txt7);
disp(txt8);