% Plot the Von Karman's model for the Gust Velocity PSD in terms of the frequency 
% in Hz, (m/s)^2/Hz and the Scaled Frequency, (m/s)^2/(rad/m). 
% RMS Gust Velocity = 1.0 m/s & L = 762 m or 2500 ft

clc
clear all
close all


% Input

% RMS of the Gust Velocity [m/s]
sig_g = 1;

% Aircraft Speed (TAS) [m/s]
V = 186;

% Turbulence's Caractheristic Scale Wavelength [m]
L = 762;

F = [];
PHI_gg = [];

OM = [];
PHI_gg_OM =[];

cont = 0;
Int_F = 0;
Int_OM = 0;

for j = -5:0.001:3

 cont = cont +1;
 
 f =  10^j;
 OMEGA = 2*pi*f/V;
 
 F = [F f];
 PHI_gg = [PHI_gg (sig_g^2)*(2*L/V)*(1+(8/3)*((1.339*OMEGA*L)^2))/((1+(1.339*OMEGA*L)^2)^(11/6))];

 OM = [OM 10^j];
 PHI_gg_OM = [PHI_gg_OM (sig_g^2)*(L/pi)*(1+(8/3)*((1.339*(10^j)*L)^2))/((1+(1.339*(10^j)*L)^2)^(11/6))];

 if cont>2 
   
 Int_F = Int_F+(F(cont)-F(cont-1))*(PHI_gg(cont)+PHI_gg(cont-1))/2;
 Int_OM = Int_OM+(OM(cont)-OM(cont-1))*(PHI_gg_OM(cont)+PHI_gg_OM(cont-1))/2;
 
 endif

 end

loglog(F,PHI_gg,'b','linewidth',2)
xlabel('Frequency [Hz]')
ylabel('PSD Gust Velocity [(m/s)^2/Hz]')
set(gca,'fontsize',15,'LineWidth',1.5)

figure
loglog(OM,PHI_gg_OM,'b','linewidth',2)
xlabel('Scaled Frequency [rad/m]')
ylabel('PSD Gust Velocity [(m/s)^2/(rad/m)]')
set(gca,'fontsize',15,'LineWidth',1.5)

txt1 = ['Gust Velocity RMS - PHI_gg integal, Frequency (Hz): ',num2str(sqrt(Int_F))];
txt2 = ['Gust Velocity RMS - PHI_gg integal, Scaled Frequency (rad/m): ',num2str(sqrt(Int_OM))];
disp(txt1);
disp(txt2);
