% Calculate the Gust Complete Response for the Flexible Aircraft considering Sharp Edged and 1-cos
% Gust Profiles and Unsteady Aerodynamics corrections applied on Wg, only.
% It is also applied the Spoiler to reduce the Gust Loads

clc
clear all
close all

% Inputs
% Speed V [m/s]
V = 56;
% Gust Length Lg [m]
Lg = 20;
% Wing Chord c [m]
c = 0.8;
% Air Density [kg/m3]
p = 1.225;
% Wing Area [m2]
Sw = 10.4;
% Aircraft Cla 
a = 2*pi;
% Tail Area [m2]
St = 2;
% AC wing to MC Aircraft lw [m]
lw = 0.3;
% AC Tail to MC Aircraft lt [m]
lt = 4;
% Tail Cla 
at = 2*pi;
% Downwash keps = deps/da
keps = 0.4;
% Aircraft mass m [kg]
m = 600;
% Aircraft Inertia I [kg.m2]
I = 400;
% Design Gust Velocity [m/s]
Wg0 = 15;
%Flexibility Parameters
% J1 integral
J1 = 0;
% J2 integral
J2 = 0;
% J3 integral
J3 = 0;
% k_et - Tail Displacement Modal Parameter
k_et = 0;
% gama_t - Tail Pitch Modal Parameter
gama_t = 0;
% Flexibility Equivalent Mass me [kg]
me = 0;
% Flexibility Equivalent Damping Ce [N.s/m]
Ce = 0;
% Flexibility Equivalent Stiffness Ke [N/m]
Ke = 0;

% t [s] between 0 and 3*Lg/V with le points
le = 301;
t  = linspace(0,3*Lg/V,le);
% Non-dimensional parameter tal
tal = (2*V/c)*t;

% Longitudinal Aerodynamic Derivatives

Za = -0.5*p*(V^2)*(Sw*a+ (1-keps)*St*at);
Zzp = -0.5*p*V*(Sw*a+ (1-keps)*St*at);
Ze= -0.5*p*(V^2)*(Sw*a*J1+ St*at*gama_t);
Zgw = -0.5*p*V*Sw*a;
Zgt = -0.5*p*V*(1-keps)*St*at;
Zap = -0.5*p*V*St*at*lt;
Zep = -0.5*p*V*St*at*k_et;

Ma = 0.5*p*(V^2)*(Sw*a*lw - (1-keps)*St*at*lt);
Mzp = 0.5*p*V*(Sw*a*lw - (1-keps)*St*at*lt);
Me= 0.5*p*(V^2)*(Sw*a*lw*J1 - St*at*lt*gama_t);
Mgw = 0.5*p*V*Sw*a*lw;
Mgt = -0.5*p*V*(1-keps)*St*at*lt;
Map = -0.5*p*V*St*at*(lt^2);
Mep = -0.5*p*V*St*at*lt*k_et;

Qa = -0.5*p*(V^2)*(Sw*a*J2+ (1-keps)*St*at*k_et);
Qzp = -0.5*p*V*(Sw*a*J2+ (1-keps)*St*at*k_et);
Qe = -0.5*p*(V^2)*(Sw*a*J3+ St*at*k_et*gama_t);
Qgw = -0.5*p*V*Sw*a*J2;
Qgt = -0.5*p*V*(1-keps)*St*at*k_et;
Qap = -0.5*p*V*St*at*lt*k_et;
Qep = -0.5*p*V*St*at*(k_et^2);




% Motion Equation Coefficients Matrices

Ca = [m 0 0; 0 I 0; 0 0 me];
Cv = [-Zzp -Zap -Zep; -Mzp -Map -Mep; -Qzp -Qap Ce-Qep];
Cd = [0 -Za -Ze; 0 -Ma -Me; 0 -Qa Ke-Qe];
Cgw = [Zgw; Mgw; Qgw];
Cgt = [Zgt; Mgt; Qgt];



dpsi = @(x)((2*x+1)*(x^2+2.82*x+0.8)-(x^2+x)*(2*x+2.82))/((x^2+2.82*x+0.8)^2);
Wg_se_c = @(x)(Wg0);

Wg_se = [];
Wg_cos = [];
Wg_se_k = [];
Wg_cos_k = [];
kuss = [];
zc =[];
vc =[];
ac =[];
aa = (a*Sw+at*St)/Sw;
eta_g = 0.5*p*V*Sw*aa/m;



 % A = Coefficient matrix to solve the Differential Equation by means of the Finite Difference Method

 A = zeros(3*le,3*le);
 B_se = zeros(3*le,1);
 B_se_k = zeros(3*le,1);
 B_cos = zeros(3*le,1);
 B_cos_k = zeros(3*le,1);
 
 L_tail =[];
 
 h = t(2)-t(1);
 mi_g = 2*m/(p*aa*Sw*c);
 
for i = 1:le

  clc
  i

  s1 = 0;
  s2 = 0;
  
  s1_t = 0;
  s2_t = 0;
  
  ta = tal(i);
  
  % Gust Penetration Effect 
  tat = tal(i)-(lt+lw)*2/c;
  
  % Steady Aerodynamics

  % Sharp Edged 
  Wg_se = [Wg_se Wg0];
   
  % 1- cos 
  Wg_cos = [Wg_cos Wgcosc(ta,Wg0,Lg,c)];
  
  % Kussner function (Analytical)
  
  kuss = [kuss Wg0*(ta^2+ta)/(ta^2+2.82*ta+0.8)];
  
  % Convolution evaluation
 % Integration interval int
if t*(i)< 0.5
 int = 0.01;
elseif t(i)<1
 int = 0.001;
elseif t(i)<1.5
int = 0.0005;  
else 
int = 0.0001; 
endif
  
  for j = 0:int:1-int
    u= (j+int)*tal(i);
    l= (j)*tal(i);
    Wg_cos_u = Wgcosc(u,Wg0,Lg,c); %see function defined on file 'Wgcosc.m'
    Wg_cos_l = Wgcosc(l,Wg0,Lg,c); %see function defined on file 'Wgcosc.m'
    s1 = s1+ (Wg0*(dpsi(tal(i)-u))+Wg0*(dpsi(tal(i)-l)))*(u-l)/2;
    s2 = s2+ (Wg_cos_u*(dpsi(tal(i)-u))+Wg_cos_l*(dpsi(tal(i)-l)))*(u-l)/2;
    
    if tat >0
    u_t= (j+int)*tat;
    l_t= (j)*tat;
    Wg_cos_u_t = Wgcosc(u_t,Wg0,Lg,c); %see function defined on file 'Wgcosc.m'
    Wg_cos_l_t = Wgcosc(l_t,Wg0,Lg,c); %see function defined on file 'Wgcosc.m'
    s1_t = s1_t+ (Wg0*(dpsi(tat-u_t))+Wg0*(dpsi(tat-l_t)))*(u_t-l_t)/2;
    s2_t = s2_t+ (Wg_cos_u_t*(dpsi(tat-u_t))+Wg_cos_l_t*(dpsi(tat-l_t)))*(u_t-l_t)/2;
    
    endif
    
  end
  
  Wg_se_k = [Wg_se_k s1];
  Wg_cos_k = [Wg_cos_k s2];
  
  % Calculate the A matrix coefficients
  
  if i == 1
    
    A (1:3,1:3) = (1/(h^2))*Ca-(1/h)*Cv+Cd;
    A (1:3,4:6) = (-2/(h^2))*Ca+ (1/h)*Cv;
    A (1:3,7:9) = (1/(h^2))*Ca;
  
  elseif i < le
    A ((i-1)*3+1:3*i,(i-2)*3+1:3*(i-1)) = (1/(h^2))*Ca; 
    A ((i-1)*3+1:3*i,(i-1)*3+1:3*(i)) = (-2/(h^2))*Ca-(1/h)*Cv+Cd;
    A ((i-1)*3+1:3*i,(i)*3+1:3*(i+1)) = (1/(h^2))*Ca+(1/h)*Cv;
 
  else
    A ((le-1)*3+1:3*le,(le-3)*3+1:3*(le-2)) = (1/(h^2))*Ca;
    A ((le-1)*3+1:3*le,(le-2)*3+1:3*(le-1)) = (-2/(h^2))*Ca-(1/h)*Cv;
    A ((le-1)*3+1:3*le,(le-1)*3+1:3*(le)) = (1/(h^2))*Ca+(1/h)*Cv+Cd;
   
 endif 
    
    if tat > 0 
      
    B_se((i-1)*3+1:3*i) =  Wg0*(Cgw+Cgt);
    B_se_k((i-1)*3+1:3*i) = s1*Cgw+s1_t*Cgt;
    B_cos((i-1)*3+1:3*i) = Wgcosc(ta,Wg0,Lg,c)*Cgw+Wgcosc(tat,Wg0,Lg,c)*Cgt;
    B_cos_k((i-1)*3+1:3*i) = s2*Cgw+s2_t*Cgt;
    
    L_tail = [L_tail s2_t*Cgt(1)];
    
  else
    
    B_se((i-1)*3+1:3*i) =  Wg0*(Cgw);
    B_se_k((i-1)*3+1:3*i) = s1*Cgw;
    B_cos((i-1)*3+1:3*i) = Wgcosc(ta,Wg0,Lg,c)*Cgw;
    B_cos_k((i-1)*3+1:3*i) = s2*Cgw;
    
    L_tail = [L_tail 0];
   
  endif
    
% Analytical Solution for the Displacement, Velocity and Acceleration    
   
% Heave Displacement (positive downwards) 

zc = [zc (Wg0/eta_g)*(1-exp(-eta_g*t(i)))-Wg0*(t(i))];

% Heave Velocity (positive downwards)

vc = [vc Wg0*exp(-eta_g*t(i))-Wg0];

% Heave Acceleration (positive downwards)

ac = [ac -eta_g*Wg0*exp(-eta_g*t(i))];

   
   
   
  end


  % Initial Conditions uc= 0 & upc = 0

  A(1:3,1:3) = eye(3,3);
  A(1:3,4:6) = zeros(3,3);
  A(1:3,7:9) = zeros(3,3);
  A(3*(le-1)+1:3*le,:) = zeros(3,3*le);
  A(3*(le-1)+1:3*le,1:3) = (-1/h)*eye(3,3);
  A(3*(le-1)+1:3*le,4:6) = (1/h)*eye(3,3);

 
 
  B_se(1:3) = 0;
  B_cos(1:3) = 0;
  B_se_k (1:3) = 0;
  B_cos_k (1:3) =0;
  
  B_se(3*(le-1)+1:3*le) = 0;
  B_cos(3*(le-1)+1:3*le) = 0;
  B_se_k (3*(le-1)+1:3*le) = 0;
  B_cos_k (3*(le-1)+1:3*le) =0;
  
% Solve the linear system and get the Vertical Displacement, Velocity and Acceleration 

% Excluding the flexibility terms:



 for i = 1:le
    
    A(3*i,3*i) = 1;
    B_se(3*i) = 0;
    B_cos(3*i) = 0;
    B_se_k (3*i) = 0;
    B_cos_k (3*i) =0;

  end
  
  u_se = inv(A)*B_se;
  u_cos = inv(A)*B_cos;
  u_se_k = inv(A)*B_se_k;
  u_cos_k = inv(A)*B_cos_k;
  
  zc_se = [];
  zc_cos = [];
  zc_se_k = [];
  zc_cos_k = [];
  
  vc_se = [];
  vc_cos = [];
  vc_se_k = [];
  vc_cos_k = [];
  
  ac_se = [];
  ac_cos = [];
  ac_se_k = [];
  ac_cos_k = [];
  
  alpha_se = [];
  alpha_cos = [];
  alpha_se_k = [];
  alpha_cos_k = [];
  
  alphap_se = [];
  alphap_cos = [];
  alphap_se_k = [];
  alphap_cos_k = [];
  
  alphapp_se = [];
  alphapp_cos = [];
  alphapp_se_k = [];
  alphapp_cos_k = [];
  
  qe_se = [];
  qe_cos = [];
  qe_se_k = [];
  qe_cos_k = [];
  
  qep_se = [];
  qep_cos = [];
  qep_se_k = [];
  qep_cos_k = [];
  
  qepp_se = [];
  qepp_cos = [];
  qepp_se_k = [];
  qepp_cos_k = [];
  
  for i = 1:le
    
    zc_se = [zc_se u_se(3*i-2)];
    zc_cos = [zc_cos u_cos(3*i-2)];
    zc_se_k = [zc_se_k u_se_k(3*i-2)];
    zc_cos_k = [zc_cos_k u_cos_k(3*i-2)];

    alpha_se = [alpha_se u_se(3*i-1)];
    alpha_cos = [alpha_cos u_cos(3*i-1)];
    alpha_se_k = [alpha_se_k u_se_k(3*i-1)];
    alpha_cos_k = [alpha_cos_k u_cos_k(3*i-1)];    

    qe_se = [qe_se u_se(3*i)];
    qe_cos = [qe_cos u_cos(3*i)];
    qe_se_k = [qe_se_k u_se_k(3*i)];
    qe_cos_k = [qe_cos_k u_cos_k(3*i)];   

end

  for i = 1:le
    
    if i == 1
      
      vc_se = [vc_se (zc_se(i+1)-zc_se(i))/h];
      vc_cos = [vc_cos (zc_cos(i+1)-zc_cos(i))/h];
      vc_se_k = [vc_se_k (zc_se_k(i+1)-zc_se_k(i))/h];
      vc_cos_k = [vc_cos_k (zc_cos_k(i+1)-zc_cos_k(i))/h];
    
      ac_se = [ac_se (zc_se(i+2)-2*zc_se(i+1)+zc_se(i))/(h^2)];
      ac_cos = [ac_cos  (zc_cos(i+2)-2*zc_cos(i+1)+zc_cos(i))/(h^2)];
      ac_se_k = [ac_se_k  (zc_se_k(i+2)-2*zc_se_k(i+1)+zc_se_k(i))/(h^2)];
      ac_cos_k = [ac_cos_k  (zc_cos_k(i+2)-2*zc_cos_k(i+1)+zc_cos_k(i))/(h^2)];

      alphap_se = [alphap_se  (alpha_se(i+1)-alpha_se(i))/h];
      alphap_cos = [alphap_cos  (alpha_cos(i+1)-alpha_cos(i))/h];
      alphap_se_k = [alphap_se_k  (alpha_se_k(i+1)-alpha_se_k(i))/h];
      alphap_cos_k = [alphap_cos_k  (alpha_cos_k(i+1)-alpha_cos_k(i))/h];
    
      alphapp_se = [alphapp_se  (alpha_se(i+2)-2*alpha_se(i+1)+alpha_se(i))/(h^2)];
      alphapp_cos = [alphapp_cos  (alpha_cos(i+2)-2*alpha_cos(i+1)+alpha_cos(i))/(h^2)];
      alphapp_se_k = [alphapp_se_k  (alpha_se_k(i+2)-2*alpha_se_k(i+1)+alpha_se_k(i))/(h^2)];
      alphapp_cos_k = [alphapp_cos_k  (alpha_cos_k(i+2)-2*alpha_cos_k(i+1)+alpha_cos_k(i))/(h^2)];
  
      qep_se = [qep_se  (qe_se(i+1)-qe_se(i))/h];
      qep_cos = [qep_cos  (qe_cos(i+1)-qe_cos(i))/h];
      qep_se_k = [qep_se_k  (qe_se_k(i+1)-qe_se_k(i))/h];
      qep_cos_k = [qep_cos_k  (qe_cos_k(i+1)-qe_cos_k(i))/h];
    
      qepp_se = [qepp_se  (qe_se(i+2)-2*qe_se(i+1)+qe_se(i))/(h^2)];
      qepp_cos = [qepp_cos  (qe_cos(i+2)-2*qe_cos(i+1)+qe_cos(i))/(h^2)];
      qepp_se_k = [qepp_se_k  (qe_se_k(i+2)-2*qe_se_k(i+1)+qe_se_k(i))/(h^2)];
      qepp_cos_k = [qepp_cos_k  (qe_cos_k(i+2)-2*qe_cos_k(i+1)+qe_cos_k(i))/(h^2)];


   
  elseif i < le
   
      
      vc_se = [vc_se  (zc_se(i+1)-zc_se(i))/h];
      vc_cos = [vc_cos  (zc_cos(i+1)-zc_cos(i))/h];
      vc_se_k = [vc_se_k  (zc_se_k(i+1)-zc_se_k(i))/h];
      vc_cos_k = [vc_cos_k  (zc_cos_k(i+1)-zc_cos_k(i))/h];
    
      ac_se = [ac_se  (zc_se(i+1)-2*zc_se(i)+zc_se(i-1))/(h^2)];
      ac_cos = [ac_cos  (zc_cos(i+1)-2*zc_cos(i)+zc_cos(i-1))/(h^2)];
      ac_se_k = [ac_se_k  (zc_se_k(i+1)-2*zc_se_k(i)+zc_se_k(i-1))/(h^2)];
      ac_cos_k = [ac_cos_k  (zc_cos_k(i+1)-2*zc_cos_k(i)+zc_cos_k(i-1))/(h^2)];

      alphap_se = [alphap_se  (alpha_se(i+1)-alpha_se(i))/h];
      alphap_cos = [alphap_cos  (alpha_cos(i+1)-alpha_cos(i))/h];
      alphap_se_k = [alphap_se_k  (alpha_se_k(i+1)-alpha_se_k(i))/h];
      alphap_cos_k = [alphap_cos_k  (alpha_cos_k(i+1)-alpha_cos_k(i))/h];
    
      alphapp_se = [alphapp_se  (alpha_se(i+1)-2*alpha_se(i)+alpha_se(i-1))/(h^2)];
      alphapp_cos = [alphapp_cos  (alpha_cos(i+1)-2*alpha_cos(i)+alpha_cos(i-1))/(h^2)];
      alphapp_se_k = [alphapp_se_k  (alpha_se_k(i+1)-2*alpha_se_k(i)+alpha_se_k(i-1))/(h^2)];
      alphapp_cos_k = [alphapp_cos_k  (alpha_cos_k(i+1)-2*alpha_cos_k(i)+alpha_cos_k(i-1))/(h^2)];

      qep_se = [qep_se  (qe_se(i+1)-qe_se(i))/h];
      qep_cos = [qep_cos  (qe_cos(i+1)-qe_cos(i))/h];
      qep_se_k = [qep_se_k  (qe_se_k(i+1)-qe_se_k(i))/h];
      qep_cos_k = [qep_cos_k  (qe_cos_k(i+1)-qe_cos_k(i))/h];
    
      qepp_se = [qepp_se  (qe_se(i+1)-2*qe_se(i)+qe_se(i-1))/(h^2)];
      qepp_cos = [qepp_cos  (qe_cos(i+1)-2*qe_cos(i)+qe_cos(i-1))/(h^2)];
      qepp_se_k = [qepp_se_k  (qe_se_k(i+1)-2*qe_se_k(i)+qe_se_k(i-1))/(h^2)];
      qepp_cos_k = [qepp_cos_k  (qe_cos_k(i+1)-2*qe_cos_k(i)+qe_cos_k(i-1))/(h^2)];
 
 
  else 
  
      vc_se = [vc_se  (zc_se(i)-zc_se(i-1))/h];
      vc_cos = [vc_cos  (zc_cos(i)-zc_cos(i-1))/h];
      vc_se_k = [vc_se_k  (zc_se_k(i)-zc_se_k(i-1))/h];
      vc_cos_k = [vc_cos_k  (zc_cos_k(i)-zc_cos_k(i-1))/h];
    
      ac_se = [ac_se  (zc_se(i)-2*zc_se(i-1)+zc_se(i-2))/(h^2)];
      ac_cos = [ac_cos  (zc_cos(i)-2*zc_cos(i-1)+zc_cos(i-2))/(h^2)];
      ac_se_k = [ac_se_k  (zc_se_k(i)-2*zc_se_k(i-1)+zc_se_k(i-2))/(h^2)];
      ac_cos_k = [ac_cos_k  (zc_cos_k(i)-2*zc_cos_k(i-1)+zc_cos_k(i-2))/(h^2)];

      alphap_se = [alphap_se  (alpha_se(i)-alpha_se(i-1))/h];
      alphap_cos = [alphap_cos  (alpha_cos(i)-alpha_cos(i-1))/h];
      alphap_se_k = [alphap_se_k  (alpha_se_k(i)-alpha_se_k(i-1))/h];
      alphap_cos_k = [alphap_cos_k  (alpha_cos_k(i)-alpha_cos_k(i-1))/h];
    
      alphapp_se = [alphapp_se  (alpha_se(i)-2*alpha_se(i-1)+alpha_se(i-2))/(h^2)];
      alphapp_cos = [alphapp_cos  (alpha_cos(i)-2*alpha_cos(i-1)+alpha_cos(i-2))/(h^2)];
      alphapp_se_k = [alphapp_se_k  (alpha_se_k(i)-2*alpha_se_k(i-1)+alpha_se_k(i-2))/(h^2)];
      alphapp_cos_k = [alphapp_cos_k  (alpha_cos_k(i)-2*alpha_cos_k(i-1)+alpha_cos_k(i-2))/(h^2)];

      qep_se = [qep_se  (qe_se(i)-qe_se(i-1))/h];
      qep_cos = [qep_cos  (qe_cos(i)-qe_cos(i-1))/h];
      qep_se_k = [qep_se_k  (qe_se_k(i)-qe_se_k(i-1))/h];
      qep_cos_k = [qep_cos_k (qe_cos_k(i)-qe_cos_k(i-1))/h];
    
      qepp_se = [qepp_se  (qe_se(i)-2*qe_se(i-1)+qe_se(i-2))/(h^2)];
      qepp_cos = [qepp_cos  (qe_cos(i)-2*qe_cos(i-1)+qe_cos(i-2))/(h^2)];
      qepp_se_k = [qepp_se_k  (qe_se_k(i)-2*qe_se_k(i-1)+qe_se_k(i-2))/(h^2)];
      qepp_cos_k = [qepp_cos_k  (qe_cos_k(i)-2*qe_cos_k(i-1)+qe_cos_k(i-2))/(h^2)];
          
      
  endif
  
end



% Usage of the Spoiler to promote the Gust Load Alleviation

alp0 = 0;

% J2sp = 1/(y2-y1)*int (y1,y2) [ke-gamae*la];

J2sp = 0; 

Zsp = -0.5*p*(V^2)*(0.7)*(c*2*4);
Msp = 0.5*p*(V^2)*(-0.1)*(c*c*2*4)-Zsp*lw;
Qsp = Zsp*J2sp



kspo = -50/35;

erro = 1;
ac_cos_k_sp = ac_cos_k;
vc_cos_k_sp = vc_cos_k;
B_sp = B_cos_k;

while erro > 0.0001
  
    dspi = kspo*-ac_cos_k_sp;
    dsp = dspi;
    
    
  for i= 1:le
    
    
    alp = (180/pi)*(Wg_cos_k(i)+vc_cos_k_sp(i))/V + alp0;
     
    if abs(alp)< 10
      lambl= 1;
      lambm = 1-alp/30;
    else
      lambl = 2-alp/10;
      lambm = 1-alp/30;
    endif
    
      
    
    if dsp(i) >0 
      dsp(i) =0;
    elseif dsp(i)<-40
      dsp(i) = -40;
    endif
    
    B_sp(3*i-2)= B_cos_k(3*i-2) + Zsp*lambl*dsp(i)*pi/180;
    B_sp(3*i-1)= B_cos_k(3*i-1) + Msp*lambm*dsp(i)*pi/180;
    B_sp(3*i)= B_cos_k(3*i) + Qsp*lambl*dsp(i)*pi/180;
end 


  B_sp (1:3) =0;
  B_sp (3*(le-1)+1:3*le) =0;


  u_cos_k_sp = inv(A)*B_sp;
  
  zc_cos_k_sp = [];
  
  vc_cos_k_sp = [];
  
  ac_cos_k_sp = [];
  
  alpha_cos_k_sp = [];
  
  alphap_cos_k_sp = [];
  
  alphapp_cos_k_sp = [];
  

  
  for i = 1:le
    
    zc_cos_k_sp = [zc_cos_k_sp u_cos_k_sp(3*i-2)];

    alpha_cos_k_sp = [alpha_cos_k_sp u_cos_k_sp(3*i-1)];    


end

  for i = 1:le
    
    if i == 1
      

      vc_cos_k_sp = [vc_cos_k_sp (zc_cos_k_sp(i+1)-zc_cos_k_sp(i))/h];
    
      ac_cos_k_sp = [ac_cos_k_sp  (zc_cos_k_sp(i+2)-2*zc_cos_k_sp(i+1)+zc_cos_k_sp(i))/(h^2)];

      alphap_cos_k_sp = [alphap_cos_k_sp  (alpha_cos_k_sp(i+1)-alpha_cos_k_sp(i))/h];
    
      alphapp_cos_k_sp = [alphapp_cos_k_sp  (alpha_cos_k_sp(i+2)-2*alpha_cos_k_sp(i+1)+alpha_cos_k_sp(i))/(h^2)];
  

   
  elseif i < le
   
      
      vc_cos_k_sp = [vc_cos_k_sp  (zc_cos_k_sp(i+1)-zc_cos_k_sp(i))/h];
    
      ac_cos_k_sp = [ac_cos_k_sp  (zc_cos_k_sp(i+1)-2*zc_cos_k_sp(i)+zc_cos_k_sp(i-1))/(h^2)];

      alphap_cos_k_sp = [alphap_cos_k_sp  (alpha_cos_k_sp(i+1)-alpha_cos_k_sp(i))/h];
    
      alphapp_cos_k_sp = [alphapp_cos_k_sp  (alpha_cos_k_sp(i+1)-2*alpha_cos_k_sp(i)+alpha_cos_k_sp(i-1))/(h^2)];
 
 
  else 
  
      vc_cos_k_sp = [vc_cos_k_sp  (zc_cos_k_sp(i)-zc_cos_k_sp(i-1))/h];

      ac_cos_k_sp = [ac_cos_k_sp  (zc_cos_k_sp(i)-2*zc_cos_k_sp(i-1)+zc_cos_k_sp(i-2))/(h^2)];

      alphap_cos_k_sp = [alphap_cos_k_sp  (alpha_cos_k_sp(i)-alpha_cos_k_sp(i-1))/h];
    
      alphapp_cos_k_sp = [alphapp_cos_k_sp  (alpha_cos_k_sp(i)-2*alpha_cos_k_sp(i-1)+alpha_cos_k_sp(i-2))/(h^2)];


  endif
  
end

 erro = norm(dspi-kspo*-ac_cos_k_sp)
 
endwhile




  
  % Gust Shape comparison

plot(t,Wg_se,'--b','LineWidth',2,t,Wg_se_k,'g','LineWidth',2,t,kuss,'--r','LineWidth',2)
xlabel('t [s]')
ylabel('Wg [m/s]')
set(gca,'fontsize',15,'LineWidth',1.5)
txt= ['"1-cos" Gust, Lg =', num2str(Lg),' m'];
legend('Sharp Edged Gust - Steady', 'Wg Kussner','Kussner Function') 

figure

plot(t,Wg_cos,'--b','LineWidth',2,t,Wg_cos_k,'g','LineWidth',2)
xlabel('t [s]')
ylabel('Wg [m/s]')
set(gca,'fontsize',15,'LineWidth',1.5)
txt= ['"1-cos" Gust, Lg =', num2str(Lg),' m - Steady'];
legend(txt, 'Wg Kussner') 

plot(t,-zc_se,'--b','LineWidth',2,t,-zc_cos,'--g','LineWidth',2,t,-zc_se_k,'b','LineWidth',2,t,-zc_cos_k,'g','LineWidth',2,t,-zc,'--r','LineWidth',2)
xlabel('t [s]')
ylabel('Heave Displacement (-zc) [m]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Sharp Edged Gust - Steady',txt,'Sharp Edged Gust - Kussner','"1-cos" - Kussner','Sharp Edged Gust - Analytical') 

figure
plot(t,-vc_se,'--b','LineWidth',2,t,-vc_cos,'--g','LineWidth',2,t,-vc_se_k,'b','LineWidth',2,t,-vc_cos_k,'g','LineWidth',2,t,-vc,'--r','LineWidth',2)
xlabel('t [s]')
ylabel('Heave Velocity (-vc) [m/s]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Sharp Edged Gust - Steady',txt,'Sharp Edged Gust - Kussner','"1-cos" - Kussner','Sharp Edged Gust - Analytical') 

figure
plot(t,-ac_se,'--b','LineWidth',2,t,-ac_cos,'--g','LineWidth',2,t,-ac_se_k,'b','LineWidth',2,t,-ac_cos_k,'g','LineWidth',2,t,-ac,'--r','LineWidth',2)
xlabel('t [s]')
ylabel('Heave Acceleration (-ac) [m/s2]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Sharp Edged Gust - Steady',txt,'Sharp Edged Gust - Kussner','"1-cos" - Kussner','Sharp Edged Gust - Analytical') 

figure

plot(t,alpha_se,'--b','LineWidth',2,t,alpha_cos,'--g','LineWidth',2,t,alpha_se_k,'b','LineWidth',2,t,alpha_cos_k,'g','LineWidth',2)
xlabel('t [s]')
ylabel('Pitch [rad]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Sharp Edged Gust - Steady',txt,'Sharp Edged Gust - Kussner','"1-cos" - Kussner') 

figure
plot(t,alphap_se,'--b','LineWidth',2,t,alphap_cos,'--g','LineWidth',2,t,alphap_se_k,'b','LineWidth',2,t,alphap_cos_k,'g','LineWidth',2)
xlabel('t [s]')
ylabel('Pitch rate [rad/s]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Sharp Edged Gust - Steady',txt,'Sharp Edged Gust - Kussner','"1-cos" - Kussner') 

figure
plot(t,alphapp_se,'--b','LineWidth',2,t,alphapp_cos,'--g','LineWidth',2,t,alphapp_se_k,'b','LineWidth',2,t,alphapp_cos_k,'g','LineWidth',2)
xlabel('t [s]')
ylabel('Pitch Acceleration [rad/s2]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Sharp Edged Gust - Steady',txt,'Sharp Edged Gust - Kussner','"1-cos" - Kussner') 


% Plot using Spoiler



figure

plot(t,-zc_cos_k,'--g','LineWidth',2,t,-zc_cos_k_sp,'b','LineWidth',2)
xlabel('t [s]')
ylabel('Heave Displacement (-zc) [m]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Without Spoiler','With Spoiler') 

figure
plot(t,-vc_cos_k,'--g','LineWidth',2,t,-vc_cos_k_sp,'b','LineWidth',2)
xlabel('t [s]')
ylabel('Heave Velocity (-vc) [m/s]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Without Spoiler','With Spoiler') 

figure
plot(t,-ac_cos_k,'--g','LineWidth',2,t,-ac_cos_k_sp,'b','LineWidth',2)
xlabel('t [s]')
ylabel('Heave Acceleration (-ac) [m/s2]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Without Spoiler','With Spoiler') 

figure

plot(t,alpha_cos_k,'--g','LineWidth',2,t,alpha_cos_k_sp,'b','LineWidth',2)
xlabel('t [s]')
ylabel('Pitch [rad]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Without Spoiler','With Spoiler') 

figure
plot(t,alphap_cos_k,'--g','LineWidth',2,t,alphap_cos_k_sp,'b','LineWidth',2)
xlabel('t [s]')
ylabel('Pitch rate [rad/s]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Without Spoiler','With Spoiler') 

figure
plot(t,alphapp_cos_k,'--g','LineWidth',2,t,alphapp_cos_k_sp,'b','LineWidth',2)
xlabel('t [s]')
ylabel('Pitch Acceleration [rad/s2]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Without Spoiler','With Spoiler') 

figure
plot(t,-dsp,'b','LineWidth',2)
xlabel('t [s]')
ylabel('Spoiler Deflection [deg]')
set(gca,'fontsize',15,'LineWidth',1.5)
 





% Load Factor Analysis

n_se_max = -min(ac_se)/9.81;
n_se_min = -max(ac_se)/9.81;

n_se_k_max = -min(ac_se_k)/9.81;
n_se_k_min = -max(ac_se_k)/9.81;

n_cos_max = -min(ac_cos)/9.81;
n_cos_min = -max(ac_cos)/9.81;

n_cos_k_max = -min(ac_cos_k)/9.81;
n_cos_k_min = -max(ac_cos_k)/9.81;

n_cos_k_sp_max = -min(ac_cos_k_sp)/9.81;
n_cos_k_sp_min = -max(ac_cos_k_sp)/9.81;

kg = 0.88*mi_g/(5.3+mi_g);

txt1 = ['Gust Alleviation Factor - Analytical Kg = ', num2str(kg)];
txt2= ['Gust Alleviation Factor - Calculated Kg = ', num2str(n_cos_k_max/(-min(ac)/9.81))];
txt3= ['Gust Alleviation Factor - Using Spoiler Kg = ', num2str(n_cos_k_sp_max/(-min(ac)/9.81))];
txt4 = ['The Total Load Factor is reduded by ',num2str(100*(1-(n_cos_k_sp_max+1)/(n_cos_k_max+1))),' %'];

disp (txt1)
disp (txt2)
disp (txt3)
disp (txt4)