% Calculate the Gust Heave Response for the Rigid Aircraft considering Sharp Edged and 1-cos
% Gust Profiles and Unsteady Aerodynamics corrections applied on Wg, only.

clc
clear all
close all

% Inputs
% Speed V [m/s]
V = 56;
% Gust Length Lg [m]
Lg = 15;
% Wing Chord c [m]
c = 0.8;
% Air Density [kg/m3]
p = 1.225;
% Wing Area [m2]
Sw = 10.4;
% Aircraft Cla 
a = 2*pi;
% Aircraft mass m [kg]
m = 600;
% Design Gust Velocity [m/s]
Wg0 = 15;
% t [s] between 0 and 3*Lg/V with le points
le = 501
t  = linspace(0,3*Lg/V,le);
% Non-dimensional parameter tal
tal = (2*V/c)*t;


dpsi = @(x)((2*x+1)*(x^2+2.82*x+0.8)-(x^2+x)*(2*x+2.82))/((x^2+2.82*x+0.8)^2);
Wg_se_c = @(x)(Wg0);


Wg_se = [];
Wg_cos = [];
Wg_se_k = [];
Wg_cos_k = [];
kuss = [];
zc =[];
vc =[];
ac =[];
eta_g = 0.5*p*V*Sw*a/m;

% Integration interval int
 int = 0.0005;

 % A = Coefficient matrix to solve the Differential Equation by means of the Finite Difference Method

 A = zeros (le,le);
 h = tal(2)-tal(1);
 mi_g = 2*m/(p*a*Sw*c);
 
for i = 1:le

  clc
  i

  s1 = 0;
  s2 = 0;
  
  ta = tal(i);
  
  % Steady Aerodynamics

  % Sharp Edged 
  Wg_se = [Wg_se Wg0];
   
  % 1- cos 
  Wg_cos = [Wg_cos Wgcosc(ta,Wg0,Lg,c)];
  
  % Kussner function (Analytical)
  
  kuss = [kuss Wg0*(ta^2+ta)/(ta^2+2.82*ta+0.8)];
  
  % Convolution evaluation
 
  
  for j = 0:int:1-int
    u= (j+int)*tal(i);
    l= (j)*tal(i);
    Wg_cos_u = Wgcosc(u,Wg0,Lg,c); %see function defined on file 'Wgcosc.m'
    Wg_cos_l = Wgcosc(l,Wg0,Lg,c); %see function defined on file 'Wgcosc.m'
    s1 = s1+ (Wg0*(dpsi(tal(i)-u))+Wg0*(dpsi(tal(i)-l)))*(u-l)/2;
    s2 = s2+ (Wg_cos_u*(dpsi(tal(i)-u))+Wg_cos_l*(dpsi(tal(i)-l)))*(u-l)/2;
  end
  
  Wg_se_k = [Wg_se_k s1];
  Wg_cos_k = [Wg_cos_k s2];
  
  % Calculate the A matrix coefficients
  
  if i == 1
    
    A (1,1) = 1/(h^2)-1/(2*mi_g*h);
    A (1,2) = -2/(h^2)+ 1/(2*mi_g*h);
    A (1,3) = 1/(h^2);
  
  elseif i < le
    A (i,i-1) = 1/(h^2); 
    A (i,i) = -2/(h^2)-1/(2*mi_g*h);
    A (i,i+1) = 1/(h^2)+1/(2*mi_g*h);
 
  else
    A (le,le-2) = 1/(h^2);
    A (le,le-1) = -2/(h^2)-1/(2*mi_g*h);
    A (le,le) = 1/(h^2)+1/(2*mi_g*h);
   
   endif 

% Analytical Solution for the Displacement, Velocity and Acceleration    
   
% Heave Displacement (positive downwards) 

zc = [zc (Wg0/eta_g)*(1-exp(-eta_g*t(i)))-Wg0*(t(i))];

% Heave Velocity (positive downwards)

vc = [vc Wg0*exp(-eta_g*t(i))-Wg0];

% Heave Acceleration (positive downwards)

ac = [ac -eta_g*Wg0*exp(-eta_g*t(i))];

   
   
   
  end

 

  B_se = Wg_se*(-1/(4*mi_g))*(c/V);
  B_cos = Wg_cos*(-1/(4*mi_g))*(c/V);
  B_se_k = Wg_se_k*(-1/(4*mi_g))*(c/V);
  B_cos_k = Wg_cos_k*(-1/(4*mi_g))*(c/V);


  % Initial Conditions zc= 0 & vc = 0

  A(1,1) = 1;
  A(1,2) = 0;
  A(1,3) = 0;
  A(le,:) =0;
  A(le,1) = -1/h;
  A(le,2) = 1/h;
 
  B_se(1) = 0;
  B_cos(1) = 0;
  B_se_k (1) = 0;
  B_cos_k (1) =0;
  
  B_se(le) = 0;
  B_cos(le) = 0;
  B_se_k (le) = 0;
  B_cos_k (le) =0;
  
  %Solve the linear system and get the Vertical Displacement, Velocity and Acceleration 
  
  zc_se = inv(A)*B_se';
  zc_cos = inv(A)*B_cos';
  zc_se_k = inv(A)*B_se_k';
  zc_cos_k = inv(A)*B_cos_k';
  
  vc_se = [];
  vc_cos = [];
  vc_se_k = [];
  vc_cos_k = [];
  
  ac_se = [];
  ac_cos = [];
  ac_se_k = [];
  ac_cos_k = [];
  
  
  for i = 1:le
    
    if i == 1
      
      vc_se = [vc_se (2*V/c)*(zc_se(i+1)-zc_se(i))/h];
      vc_cos = [vc_cos (2*V/c)*(zc_cos(i+1)-zc_cos(i))/h];
      vc_se_k = [vc_se_k (2*V/c)*(zc_se_k(i+1)-zc_se_k(i))/h];
      vc_cos_k = [vc_cos_k (2*V/c)*(zc_cos_k(i+1)-zc_cos_k(i))/h];
    
      ac_se = [ac_se ((2*V/c)^2)*(zc_se(i+2)-2*zc_se(i+1)+zc_se(i))/(h^2)];
      ac_cos = [ac_cos ((2*V/c)^2)*(zc_cos(i+2)-2*zc_cos(i+1)+zc_cos(i))/(h^2)];
      ac_se_k = [ac_se_k ((2*V/c)^2)*(zc_se_k(i+2)-2*zc_se_k(i+1)+zc_se_k(i))/(h^2)];
      ac_cos_k = [ac_cos_k ((2*V/c)^2)*(zc_cos_k(i+2)-2*zc_cos_k(i+1)+zc_cos_k(i))/(h^2)];
   
  elseif i < le
   
      
      vc_se = [vc_se (2*V/c)*(zc_se(i+1)-zc_se(i))/h];
      vc_cos = [vc_cos (2*V/c)*(zc_cos(i+1)-zc_cos(i))/h];
      vc_se_k = [vc_se_k (2*V/c)*(zc_se_k(i+1)-zc_se_k(i))/h];
      vc_cos_k = [vc_cos_k (2*V/c)*(zc_cos_k(i+1)-zc_cos_k(i))/h];
    
      ac_se = [ac_se ((2*V/c)^2)*(zc_se(i+1)-2*zc_se(i)+zc_se(i-1))/(h^2)];
      ac_cos = [ac_cos ((2*V/c)^2)*(zc_cos(i+1)-2*zc_cos(i)+zc_cos(i-1))/(h^2)];
      ac_se_k = [ac_se_k ((2*V/c)^2)*(zc_se_k(i+1)-2*zc_se_k(i)+zc_se_k(i-1))/(h^2)];
      ac_cos_k = [ac_cos_k ((2*V/c)^2)*(zc_cos_k(i+1)-2*zc_cos_k(i)+zc_cos_k(i-1))/(h^2)];
  
  else 
  
      vc_se = [vc_se (2*V/c)*(zc_se(i)-zc_se(i-1))/h];
      vc_cos = [vc_cos (2*V/c)*(zc_cos(i)-zc_cos(i-1))/h];
      vc_se_k = [vc_se_k (2*V/c)*(zc_se_k(i)-zc_se_k(i-1))/h];
      vc_cos_k = [vc_cos_k (2*V/c)*(zc_cos_k(i)-zc_cos_k(i-1))/h];
    
      ac_se = [ac_se ((2*V/c)^2)*(zc_se(i)-2*zc_se(i-1)+zc_se(i-2))/(h^2)];
      ac_cos = [ac_cos ((2*V/c)^2)*(zc_cos(i)-2*zc_cos(i-1)+zc_cos(i-2))/(h^2)];
      ac_se_k = [ac_se_k ((2*V/c)^2)*(zc_se_k(i)-2*zc_se_k(i-1)+zc_se_k(i-2))/(h^2)];
      ac_cos_k = [ac_cos_k ((2*V/c)^2)*(zc_cos_k(i)-2*zc_cos_k(i-1)+zc_cos_k(i-2))/(h^2)];

      
  endif
  
end

  
  % Gust Shape comparison

plot(t,Wg_se,'--b','LineWidth',2,t,Wg_se_k,'g','LineWidth',2,t,kuss,'--r','LineWidth',2)
xlabel('t [s]')
ylabel('Wg [m/s]')
set(gca,'fontsize',15,'LineWidth',1.5)
txt= ['"1-cos" Gust, Lg =', num2str(Lg),' m'];
legend('Sharp Edged Gust - Steady', 'Wg Kussner','Kussner Function') 

figure

plot(t,Wg_cos,'--b','LineWidth',2,t,Wg_cos_k,'g','LineWidth',2)
xlabel('t [s]')
ylabel('Wg [m/s]')
set(gca,'fontsize',15,'LineWidth',1.5)
txt= ['"1-cos" Gust, Lg =', num2str(Lg),' m - Steady'];
legend(txt, 'Wg Kussner') 

figure

plot(t,-zc_se,'--b','LineWidth',2,t,-zc_cos,'--g','LineWidth',2,t,-zc_se_k,'b','LineWidth',2,t,-zc_cos_k,'g','LineWidth',2,t,-zc,'--r','LineWidth',2)
xlabel('t [s]')
ylabel('Heave Displacement (-zc) [m]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Sharp Edged Gust - Steady',txt,'Sharp Edged Gust - Kussner','"1-cos" - Kussner','Sharp Edged Gust - Analytical') 

figure
plot(t,-vc_se,'--b','LineWidth',2,t,-vc_cos,'--g','LineWidth',2,t,-vc_se_k,'b','LineWidth',2,t,-vc_cos_k,'g','LineWidth',2,t,-vc,'--r','LineWidth',2)
xlabel('t [s]')
ylabel('Heave Velocity (-vc) [m/s]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Sharp Edged Gust - Steady',txt,'Sharp Edged Gust - Kussner','"1-cos" - Kussner','Sharp Edged Gust - Analytical') 

figure
plot(t,-ac_se,'--b','LineWidth',2,t,-ac_cos,'--g','LineWidth',2,t,-ac_se_k,'b','LineWidth',2,t,-ac_cos_k,'g','LineWidth',2,t,-ac,'--r','LineWidth',2)
xlabel('t [s]')
ylabel('Heave Acceleration (-ac) [m/s2]')
set(gca,'fontsize',15,'LineWidth',1.5)
legend('Sharp Edged Gust - Steady',txt,'Sharp Edged Gust - Kussner','"1-cos" - Kussner','Sharp Edged Gust - Analytical') 

% Load Factor Analysis

n_se_max = -min(ac_se)/9.81;
n_se_min = -max(ac_se)/9.81;

n_se_k_max = -min(ac_se_k)/9.81;
n_se_k_min = -max(ac_se_k)/9.81;

n_cos_max = -min(ac_cos)/9.81;
n_cos_min = -max(ac_cos)/9.81;

n_cos_k_max = -min(ac_cos_k)/9.81;
n_cos_k_min = -max(ac_cos_k)/9.81;

kg = 0.88*mi_g/(5.3+mi_g);

txt1 = ['Gust Alleviation Factor - Analytical Kg = ', num2str(kg)];
txt2= ['Gust Alleviation Factor - Calculated Kg = ', num2str(n_cos_k_max/n_se_max)];
disp (txt1)
disp (txt2)



 
