% Calculate the equivalent Kussner Gust velocity profile using the 
% Unsteady Aerodynamics corrections

clc
clear all
close all

% Inputs
% Speed V [m/s]
V = 56;
% Gust Length Lg [m]
Lg = 15;
% Wing Chord c [m]
c = 0.8;
% t [s] between 0 and Lg/V with 101 points
t  = linspace(0,Lg/V,101);
% Non-dimensional parameter tal
tal = (2*V/c)*t;
% Design Gust Velocity [m/s]
Wg0 = 15;

% Gust Velocity Profile]

% Steady Aerodynamics

% Sharp Edged 
Wg_se = Wg0*ones(1,101);
% 1- cos 
Wg_cos = Wg0/2*(1-cos(2*pi*V*t./Lg));


% Unsteady Aerodynamics

% t [s] between 0 and Lg/V with 101 points
t2  = linspace(0,3*Lg/V,101);
% Non-dimensional parameter tal
tal = (2*V/c)*t2;

dpsi = @(x)((2*x+1)*(x^2+2.82*x+0.8)-(x^2+x)*(2*x+2.82))/((x^2+2.82*x+0.8)^2);
Wg_se_c = @(x)(Wg0);


Wg_se_k = [];
Wg_cos_k = [];
kuss = [];

% Integration interval int
 int = 0.001;

for i = 1:101

  clc
  i

  s1 = 0;
  s2 = 0;
  
  ta = tal(i);
  
  kuss = [kuss Wg0*(ta^2+ta)/(ta^2+2.82*ta+0.8)];
  
  % Convolution evaluation
 
  
  for j = 0:int:1-int
    u= (j+int)*tal(i);
    l= (j)*tal(i);
    Wg_cos_u = Wgcosc(u,Wg0,Lg,c); %see function defined on file 'Wgcosc.m'
    Wg_cos_l = Wgcosc(l,Wg0,Lg,c); %see function defined on file 'Wgcosc.m'
    s1 = s1+ (Wg0*(dpsi(tal(i)-u))+Wg0*(dpsi(tal(i)-l)))*(u-l)/2;
    s2 = s2+ (Wg_cos_u*(dpsi(tal(i)-u))+Wg_cos_l*(dpsi(tal(i)-l)))*(u-l)/2;
  end
  
  Wg_se_k = [Wg_se_k s1];
  Wg_cos_k = [Wg_cos_k s2];
  
  end

  % Gust Shape comparison

plot(t2,Wg_se,'--b','LineWidth',2,t2,Wg_se_k,'g','LineWidth',2,t2,kuss,'--r','LineWidth',2)
xlabel('t [s]')
ylabel('Wg [m/s]')
set(gca,'fontsize',15,'LineWidth',1.5)
txt= ['"1-cos" Gust, Lg =', num2str(Lg),' m'];
legend('Sharp Edged Gust - Steady', 'Wg Kussner','Kussner Function') 

figure

plot(t,Wg_cos,'--b','LineWidth',2,t2,Wg_cos_k,'g','LineWidth',2)
xlabel('t [s]')
ylabel('Wg [m/s]')
set(gca,'fontsize',15,'LineWidth',1.5)
txt= ['"1-cos" Gust, Lg =', num2str(Lg),' m - Steady'];
legend(txt, 'Wg Kussner') 




