% Gust Response for a Sharp Edged Gust, Rigid Aircraft and just Heave motion considered

clc
clear all
close all

% Inputs

% Speed V [m/s]
V = 56;
% Air Density [kg/m3]
p = 1.225;
% Wing Area [m2]
Sw = 10.4;
% Aircraft Cla 
a = 2*pi;
% Aircraft mass m [kg]
m = 600;
% Design Gust Velocity [m/s]
Wg0 = 15;
% t [s] between 0 and 5 with 101 points
t  = linspace(0,5,101);

% Gust Response

zc = [];
vc =[];
ac =[];

eta_g = 0.5*p*V*Sw*a/m;

for i = 1:101

% Heave Displacement (positive downwards) 

zc = [zc (Wg0/eta_g)*(1-exp(-eta_g*t(i)))-Wg0*(t(i))];

% Heave Velocity (positive downwards)

vc = [vc Wg0*exp(-eta_g*t(i))-Wg0];

% Heave Acceleration (positive downwards)

ac = [ac -eta_g*Wg0*exp(-eta_g*t(i))];

end 


% Maximum Delta Load Factor dn (positive upwards - standard)

dn = p*V*Wg0*a/(2*(m*9.81/Sw));

% Response Plotting 

plot(t,-zc,'b','LineWidth',2)
xlabel('t [s]')
ylabel('Heave Displacement (-zc) [m]')
set(gca,'fontsize',15,'LineWidth',1.5)

figure
plot(t,-vc,'b','LineWidth',2, [0,5],[15,15],'--g','LineWidth',2)
xlabel('t [s]')
ylabel('Heave Velocity (-vc) [m/s]')
set(gca,'fontsize',15,'LineWidth',1.5)

figure
plot(t,-ac,'b','LineWidth',2)
xlabel('t [s]')
ylabel('Heave Acceleration (-ac) [m/s2]')
set(gca,'fontsize',15,'LineWidth',1.5)

txt= ['Maximum Delta Load Factor = ', num2str(dn)];
disp(txt)